Libvirt MI
=========

This workspace provisions a linchpin multinode template.  This template can be used to provision a set of instance of different
operating systems and architectures.

`instance` is list of dictionary objects containing an arch and operating system
